@@ -49,14 +49,6 @@ class SectionsTree:
             return [node for node in PreOrderIter(search_from_node, filter_=lambda n: hasattr(n, "text"))]
         return []
 
-    def get_leaf_sections_names(self, section_name="Техническое задание") -> list:
-        """
-        Возвращает список имён листовых элементов дерева разделов относительно корневого раздела.
-        Если явно указан параметр `section_name`, то возвращается список имён листовых элементов относительно
-        одноимённого раздела.
-        """
-        return [node.name for node in self.get_leaf_sections(section_name)]
-
     def get_content(self, section_name="Техническое задание") -> str:
         """
         Возвращает содержимое дерева разделов (совокупность значений всех полей `text`) относительно корневого раздела.
