@@ -6,12 +6,9 @@ from docx.oxml.table import CT_Tbl
 from docx.oxml.text.paragraph import CT_P
 from docx.table import _Cell, Table
 from docx.text.paragraph import Paragraph
-from gensim.similarities import SparseMatrixSimilarity
-from gensim.utils import simple_preprocess
-from gensim.corpora.dictionary import Dictionary
-from gensim.models.tfidfmodel import TfidfModel
 
 from srsparser import configs
+from srsparser.nlp import strings_similarity
 from srsparser.sections_tree import SectionsTree
 
 
@@ -28,24 +25,6 @@ class Parser:
         """
         self.sections_tree = SectionsTree(sections_tree_template)
 
-        # создаём список, состоящий из элементов,
-        # каждый из которых представлен списком слов заголовков листовых разделов
-        self.leaf_section_headings = self.sections_tree.get_leaf_sections_names()
-        gen_docs = [[word for word in simple_preprocess(name, min_len=1, max_len=50)]
-                    for name in self.leaf_section_headings]
-
-        # сопоставляем каждое слово с уникальным идентификатором (образование словаря)
-        self.dictionary = Dictionary(gen_docs)
-
-        # создаём корпус (набор слов), который содержит идентификатор слова и его частоту в каждом документе (разделе)
-        # (перечисляет, сколько раз слово встретилось в предложении)
-        corpus = [self.dictionary.doc2bow(gen_doc) for gen_doc in gen_docs]
-
-        # TF-IDF веса слов для всех документов (разделов)
-        self.tf_idf = TfidfModel(corpus, smartirs="ltc")
-
-        self.similarity = SparseMatrixSimilarity(self.tf_idf[corpus], num_features=len(self.dictionary))
-
     def parse_docx(self, path: str) -> dict:
         """
         Возвращает заполненную в соответствии с содержимым текстового документа с ТЗ структуру дерева разделов.
@@ -84,7 +63,7 @@ class Parser:
 
             if self.is_heading_of_sec(p_text_split[0]) and not self.is_table_element(paragraph, doc):
                 if p_text_split[0] != "" and p_text_split[1] != "":
-                    result[p_text_split[0]] = paragraph.text
+                    result[p_text_split[0]] = p_text_split[1].strip()
         return result
 
     def get_sections_second(self, doc: Document) -> dict:
@@ -103,10 +82,10 @@ class Parser:
                 if curr_heading_text != "":
                     result[curr_heading_text] = "\n".join(curr_heading_paragraphs)
 
-                curr_heading_text = paragraph.text
+                curr_heading_text = paragraph.text.strip()
                 curr_heading_paragraphs.clear()
             else:
-                curr_heading_paragraphs.append(re.sub(configs.NUMBERING_PATTERN, "", paragraph.text))
+                curr_heading_paragraphs.append(re.sub(configs.NUMBERING_PATTERN, "", paragraph.text.strip()))
         result[curr_heading_text] = "\n".join(curr_heading_paragraphs)
         return result
 
@@ -117,16 +96,11 @@ class Parser:
         for heading, text in headings_with_texts.items():
             max_ratio = 0
             text_parent = None
-
-            query_doc = [word for word in simple_preprocess(heading, min_len=1, max_len=50)]
-            query_doc_bow = self.dictionary.doc2bow(query_doc)
-            query_doc_tf_idf = self.tf_idf[query_doc_bow]
-
-            for i in range(len(self.similarity[query_doc_tf_idf])):
-                if self.similarity[query_doc_tf_idf][i] > max_ratio:
-                    max_ratio = self.similarity[query_doc_tf_idf][i]
-                    text_parent = self.sections_tree.get_leaf_sections()[i]
-
+            for section in self.sections_tree.get_leaf_sections():
+                ratio = strings_similarity(section.name, heading)
+                if ratio >= max_ratio:
+                    max_ratio = ratio
+                    text_parent = section
             if text_parent is not None:
                 text_parent.text = text.strip()
 
@@ -154,11 +128,10 @@ class Parser:
 
         :return: True — да, иначе — False.
         """
-        query_doc = [word for word in simple_preprocess(p_text, min_len=1, max_len=50)]
-        query_doc_bow = self.dictionary.doc2bow(query_doc)
-        query_doc_tf_idf = self.tf_idf[query_doc_bow]
-        text_similarity_ratio = max(self.similarity[query_doc_tf_idf])
-        return text_similarity_ratio >= configs.MIN_SIMILARITY_RATIO
+        for section in self.sections_tree.get_leaf_sections():
+            if strings_similarity(section.name, p_text) >= configs.MIN_SIMILARITY_RATIO:
+                return True
+        return False
 
     @staticmethod
     def is_table_element(paragraph: Paragraph, doc: Document) -> bool:
